==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/relateandunrelate/impl/RelateSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.relateandunrelate.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.Relate;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class RelateSetImpl extends InstanceSet<RelateSet,Relate> implements RelateSet {

    // attributes
    @Override
    public void setOne_Side_Var_ID( UniqueId ref_One_Side_Var_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setOne_Side_Var_ID( ref_One_Side_Var_ID );
    }
    @Override
    public void setAssociationPhraseLineNumber( int m_associationPhraseLineNumber ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationPhraseLineNumber( m_associationPhraseLineNumber );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setRelationship_phrase( String m_relationship_phrase ) throws XtumlException {
        for ( Relate relate : this ) relate.setRelationship_phrase( m_relationship_phrase );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setAssociationNumberColumn( int m_associationNumberColumn ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationNumberColumn( m_associationNumberColumn );
    }
    @Override
    public void setAssociationPhraseColumn( int m_associationPhraseColumn ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationPhraseColumn( m_associationPhraseColumn );
    }
    @Override
    public void setOther_Side_Var_ID( UniqueId ref_Other_Side_Var_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setOther_Side_Var_ID( ref_Other_Side_Var_ID );
    }
    @Override
    public void setAssociationNumberLineNumber( int m_associationNumberLineNumber ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationNumberLineNumber( m_associationNumberLineNumber );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( Relate relate : this ) act_smtset.add( relate.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_VARSet R615_one_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Relate relate : this ) v_varset.add( relate.R615_one_V_VAR() );
        return v_varset;
    }
    @Override
    public V_VARSet R616_other_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Relate relate : this ) v_varset.add( relate.R616_other_V_VAR() );
        return v_varset;
    }
    @Override
    public AssociationSet R653_creates_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( Relate relate : this ) associationset.add( relate.R653_creates_Association() );
        return associationset;
    }


    @Override
    public Relate nullElement() {
        return RelateImpl.EMPTY_RELATE;
    }

    @Override
    public RelateSet emptySet() {
      return new RelateSetImpl();
    }

    @Override
    public RelateSet value() {
        return this;
    }

    @Override
    public List<Relate> elements() {
        return Arrays.asList(toArray(new Relate[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/relateandunrelate/impl/RelateSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.relateandunrelate.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.Relate;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class RelateSetImpl extends InstanceSet<RelateSet,Relate> implements RelateSet {

    public RelateSetImpl() {
    }

    public RelateSetImpl(Comparator<? super Relate> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRelationship_phrase( String m_relationship_phrase ) throws XtumlException {
        for ( Relate relate : this ) relate.setRelationship_phrase( m_relationship_phrase );
    }
    @Override
    public void setAssociationNumberColumn( int m_associationNumberColumn ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationNumberColumn( m_associationNumberColumn );
    }
    @Override
    public void setAssociationNumberLineNumber( int m_associationNumberLineNumber ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationNumberLineNumber( m_associationNumberLineNumber );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setAssociationPhraseLineNumber( int m_associationPhraseLineNumber ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationPhraseLineNumber( m_associationPhraseLineNumber );
    }
    @Override
    public void setAssociationPhraseColumn( int m_associationPhraseColumn ) throws XtumlException {
        for ( Relate relate : this ) relate.setAssociationPhraseColumn( m_associationPhraseColumn );
    }
    @Override
    public void setOther_Side_Var_ID( UniqueId ref_Other_Side_Var_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setOther_Side_Var_ID( ref_Other_Side_Var_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setOne_Side_Var_ID( UniqueId ref_One_Side_Var_ID ) throws XtumlException {
        for ( Relate relate : this ) relate.setOne_Side_Var_ID( ref_One_Side_Var_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( Relate relate : this ) act_smtset.add( relate.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_VARSet R615_one_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Relate relate : this ) v_varset.add( relate.R615_one_V_VAR() );
        return v_varset;
    }
    @Override
    public V_VARSet R616_other_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Relate relate : this ) v_varset.add( relate.R616_other_V_VAR() );
        return v_varset;
    }
    @Override
    public AssociationSet R653_creates_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( Relate relate : this ) associationset.add( relate.R653_creates_Association() );
        return associationset;
    }


    @Override
    public Relate nullElement() {
        return RelateImpl.EMPTY_RELATE;
    }

    @Override
    public RelateSet emptySet() {
      return new RelateSetImpl();
    }

    @Override
    public RelateSet emptySet(Comparator<? super Relate> comp) {
      return new RelateSetImpl(comp);
    }

    @Override
    public RelateSet value() {
        return this;
    }

    @Override
    public List<Relate> elements() {
        return Arrays.asList(toArray(new Relate[0]));
    }

}
